==> mappingservice.api-1.7.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/lfm/mappingservice/rev150906/eid/authkey/list/EidAuthkeyItemKey.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.lfm.mappingservice.rev150906.eid.authkey.list;
import org.opendaylight.yangtools.yang.binding.Identifier;
import java.util.Objects;

public class EidAuthkeyItemKey
 implements Identifier<EidAuthkeyItem> {
    private static final long serialVersionUID = 3908499816011096474L;
    private final java.lang.String _eidAuthkeyItemId;


    public EidAuthkeyItemKey(java.lang.String _eidAuthkeyItemId) {
    
    
        this._eidAuthkeyItemId = _eidAuthkeyItemId;
    }
    
    /**
     * Creates a copy from Source Object.
     *
     * @param source Source object
     */
    public EidAuthkeyItemKey(EidAuthkeyItemKey source) {
        this._eidAuthkeyItemId = source._eidAuthkeyItemId;
    }


    public java.lang.String getEidAuthkeyItemId() {
        return _eidAuthkeyItemId;
    }


    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + Objects.hashCode(_eidAuthkeyItemId);
        return result;
    }

    @Override
    public boolean equals(java.lang.Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        EidAuthkeyItemKey other = (EidAuthkeyItemKey) obj;
        if (!Objects.equals(_eidAuthkeyItemId, other._eidAuthkeyItemId)) {
            return false;
        }
        return true;
    }

    @Override
    public java.lang.String toString() {
        java.lang.StringBuilder builder = new java.lang.StringBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.lfm.mappingservice.rev150906.eid.authkey.list.EidAuthkeyItemKey.class.getSimpleName()).append(" [");
        boolean first = true;
    
        if (_eidAuthkeyItemId != null) {
            if (first) {
                first = false;
            } else {
                builder.append(", ");
            }
            builder.append("_eidAuthkeyItemId=");
            builder.append(_eidAuthkeyItemId);
        }
        return builder.append(']').toString();
    }
}

==> mappingservice.api-1.10.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/lfm/mappingservice/rev150906/eid/authkey/list/EidAuthkeyItemKey.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.lfm.mappingservice.rev150906.eid.authkey.list;
import com.google.common.base.MoreObjects;
import java.lang.Override;
import java.lang.String;
import java.util.Objects;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.Identifier;

public class EidAuthkeyItemKey
 implements Identifier<EidAuthkeyItem> {
    private static final long serialVersionUID = 3908499816011096474L;
    private final String _eidAuthkeyItemId;


    public EidAuthkeyItemKey(String _eidAuthkeyItemId) {
    
    
        this._eidAuthkeyItemId = _eidAuthkeyItemId;
    }
    
    /**
     * Creates a copy from Source Object.
     *
     * @param source Source object
     */
    public EidAuthkeyItemKey(EidAuthkeyItemKey source) {
        this._eidAuthkeyItemId = source._eidAuthkeyItemId;
    }


    public String getEidAuthkeyItemId() {
        return _eidAuthkeyItemId;
    }


    @Override
    public int hashCode() {
        return CodeHelpers.wrapperHashCode(_eidAuthkeyItemId);
    }

    @Override
    public boolean equals(java.lang.Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        EidAuthkeyItemKey other = (EidAuthkeyItemKey) obj;
        if (!Objects.equals(_eidAuthkeyItemId, other._eidAuthkeyItemId)) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper(EidAuthkeyItemKey.class);
        CodeHelpers.appendValue(helper, "_eidAuthkeyItemId", _eidAuthkeyItemId);
        return helper.toString();
    }
}
